@@ -1,6 +1,9 @@
 from nwon_django_toolbox.typings.celery import CeleryFolder, CeleryReturn
 from nwon_django_toolbox.typings.django_ready_enum import DjangoReadyEnum
 from nwon_django_toolbox.typings.error_response import ErrorResponse
+from nwon_django_toolbox.typings.permission_test_expectation import (
+    PermissionTestExpectation,
+)
 from nwon_django_toolbox.typings.pydantic_base_django import PydanticBaseDjango
 from nwon_django_toolbox.typings.request_body_format import RequestBodyFormat
 from nwon_django_toolbox.typings.test_fixture import TestFixture
